LockToken

Struct LockToken 

pub struct LockToken<T> { /* private fields */ }
A token indicating a locked interface.

Implementations

Source

impl LockToken<Unlock>

pub unsafe fn relinquish_locking(self) -> LockToken<ForgetUnlock>

Takes ownership of the token and exchanges it with a token which does not unlock the interface.

Safety

Improper usage can leave the interface in a locked state.

Source

impl LockToken<ForgetUnlock>

pub unsafe fn take_ownership(self) -> LockToken<Unlock>

Takes ownership of the token and exchanges it with a token which unlocks the interface.

Safety

Improper usage can unlock the interface multiple times.

Source

impl<T> LockToken<T>

pub fn lock() -> LockToken<Unlock>

Constructs a new token by locking the interface.

The calling thread is stalled until the lock can be acquired. Only one thread can hold the lock at a time.

Return

A token.

pub fn try_lock() -> Option<LockToken<Unlock>>

Tries to lock the interface.

The function fails if another thread already holds the lock.

Return

LockToken on success and None otherwise.

pub unsafe fn assume_locked() -> LockToken<ForgetUnlock>

Constructs a new token without locking.

Return

A token.

Safety

Most of the interface assumes that the caller has unique access to the interface. This function can be used to bypass this restriction, if the user can guarantee that no data-races will occur.